Module contracts_api

Module contracts_api 

Enums

AcceptContractError
struct for typed errors of method accept_contract
DeliverContractError
struct for typed errors of method deliver_contract
FulfillContractError
struct for typed errors of method fulfill_contract
GetContractError
struct for typed errors of method get_contract
GetContractsError
struct for typed errors of method get_contracts

Functions

accept_contract
Accept a contract by ID. You can only accept contracts that were offered to you, were not accepted yet, and whose deadlines has not passed yet.
deliver_contract
Deliver cargo to a contract. In order to use this API, a ship must be at the delivery location (denoted in the delivery terms as destinationSymbol of a contract) and must have a number of units of a good required by this contract in its cargo. Cargo that was delivered will be removed from the ship’s cargo.
fulfill_contract
Fulfill a contract. Can only be used on contracts that have all of their delivery terms fulfilled.
get_contract
Get the details of a contract by ID.
get_contracts
Return a paginated list of all your contracts.