Module fleet_api

Module fleet_api 

Enums

CreateChartError
struct for typed errors of method create_chart
CreateShipShipScanError
struct for typed errors of method create_ship_ship_scan
CreateShipSystemScanError
struct for typed errors of method create_ship_system_scan
CreateShipWaypointScanError
struct for typed errors of method create_ship_waypoint_scan
CreateSurveyError
struct for typed errors of method create_survey
DockShipError
struct for typed errors of method dock_ship
ExtractResourcesError
struct for typed errors of method extract_resources
ExtractResourcesWithSurveyError
struct for typed errors of method extract_resources_with_survey
GetMountsError
struct for typed errors of method get_mounts
GetMyShipCargoError
struct for typed errors of method get_my_ship_cargo
GetMyShipError
struct for typed errors of method get_my_ship
GetMyShipsError
struct for typed errors of method get_my_ships
GetRepairShipError
struct for typed errors of method get_repair_ship
GetScrapShipError
struct for typed errors of method get_scrap_ship
GetShipCooldownError
struct for typed errors of method get_ship_cooldown
GetShipModulesError
struct for typed errors of method get_ship_modules
GetShipNavError
struct for typed errors of method get_ship_nav
InstallMountError
struct for typed errors of method install_mount
InstallShipModuleError
struct for typed errors of method install_ship_module
JettisonError
struct for typed errors of method jettison
JumpShipError
struct for typed errors of method jump_ship
NavigateShipError
struct for typed errors of method navigate_ship
NegotiateContractError
struct for typed errors of method negotiate_contract
OrbitShipError
struct for typed errors of method orbit_ship
PatchShipNavError
struct for typed errors of method patch_ship_nav
PurchaseCargoError
struct for typed errors of method purchase_cargo
PurchaseShipError
struct for typed errors of method purchase_ship
RefuelShipError
struct for typed errors of method refuel_ship
RemoveMountError
struct for typed errors of method remove_mount
RemoveShipModuleError
struct for typed errors of method remove_ship_module
RepairShipError
struct for typed errors of method repair_ship
ScrapShipError
struct for typed errors of method scrap_ship
SellCargoError
struct for typed errors of method sell_cargo
ShipRefineError
struct for typed errors of method ship_refine
SiphonResourcesError
struct for typed errors of method siphon_resources
TransferCargoError
struct for typed errors of method transfer_cargo
WarpShipError
struct for typed errors of method warp_ship

Functions

create_chart
Command a ship to chart the waypoint at its current location. Most waypoints in the universe are uncharted by default. These waypoints have their traits hidden until they have been charted by a ship. Charting a waypoint will record your agent as the one who created the chart, and all other agents would also be able to see the waypoint’s traits. Charting a waypoint gives you a one time reward of credits based on the rarity of the waypoint’s traits.
create_ship_ship_scan
Scan for nearby ships, retrieving information for all ships in range. Requires a ship to have the Sensor Array mount installed to use. The ship will enter a cooldown after using this function, during which it cannot execute certain actions.
create_ship_system_scan
Scan for nearby systems, retrieving information on the systems’ distance from the ship and their waypoints. Requires a ship to have the Sensor Array mount installed to use. The ship will enter a cooldown after using this function, during which it cannot execute certain actions.
create_ship_waypoint_scan
Scan for nearby waypoints, retrieving detailed information on each waypoint in range. Scanning uncharted waypoints will allow you to ignore their uncharted state and will list the waypoints’ traits. Requires a ship to have the Sensor Array mount installed to use. The ship will enter a cooldown after using this function, during which it cannot execute certain actions.
create_survey
Create surveys on a waypoint that can be extracted such as asteroid fields. A survey focuses on specific types of deposits from the extracted location. When ships extract using this survey, they are guaranteed to procure a high amount of one of the goods in the survey. In order to use a survey, send the entire survey details in the body of the extract request. Each survey may have multiple deposits, and if a symbol shows up more than once, that indicates a higher chance of extracting that resource. Your ship will enter a cooldown after surveying in which it is unable to perform certain actions. Surveys will eventually expire after a period of time or will be exhausted after being extracted several times based on the survey’s size. Multiple ships can use the same survey for extraction. A ship must have the Surveyor mount installed in order to use this function.
dock_ship
Attempt to dock your ship at its current location. Docking will only succeed if your ship is capable of docking at the time of the request. Docked ships can access elements in their current location, such as the market or a shipyard, but cannot do actions that require the ship to be above surface such as navigating or extracting. The endpoint is idempotent - successive calls will succeed even if the ship is already docked.
extract_resources
Extract resources from a waypoint that can be extracted, such as asteroid fields, into your ship. Send an optional survey as the payload to target specific yields. The ship must be in orbit to be able to extract and must have mining equipments installed that can extract goods, such as the Gas Siphon mount for gas-based goods or Mining Laser mount for ore-based goods. The survey property is now deprecated. See the extract/survey endpoint for more details.
extract_resources_with_survey
Use a survey when extracting resources from a waypoint. This endpoint requires a survey as the payload, which allows your ship to extract specific yields. Send the full survey object as the payload which will be validated according to the signature. If the signature is invalid, or any properties of the survey are changed, the request will fail.
get_mounts
Get the mounts installed on a ship.
get_my_ship
Retrieve the details of a ship under your agent’s ownership.
get_my_ship_cargo
Retrieve the cargo of a ship under your agent’s ownership.
get_my_ships
Return a paginated list of all of ships under your agent’s ownership.
get_repair_ship
Get the cost of repairing a ship.
get_scrap_ship
Get the amount of value that will be returned when scrapping a ship.
get_ship_cooldown
Retrieve the details of your ship’s reactor cooldown. Some actions such as activating your jump drive, scanning, or extracting resources taxes your reactor and results in a cooldown. Your ship cannot perform additional actions until your cooldown has expired. The duration of your cooldown is relative to the power consumption of the related modules or mounts for the action taken. Response returns a 204 status code (no-content) when the ship has no cooldown.
get_ship_modules
Get the modules installed on a ship.
get_ship_nav
Get the current nav status of a ship.
install_mount
Install a mount on a ship. In order to install a mount, the ship must be docked and located in a waypoint that has a Shipyard trait. The ship also must have the mount to install in its cargo hold. An installation fee will be deduced by the Shipyard for installing the mount on the ship.
install_ship_module
Install a module on a ship. The module must be in your cargo.
jettison
Jettison cargo from your ship’s cargo hold.
jump_ship
Jump your ship instantly to a target connected waypoint. The ship must be in orbit to execute a jump. A unit of antimatter is purchased and consumed from the market when jumping. The price of antimatter is determined by the market and is subject to change. A ship can only jump to connected waypoints
navigate_ship
Navigate to a target destination. The ship must be in orbit to use this function. The destination waypoint must be within the same system as the ship’s current location. Navigating will consume the necessary fuel from the ship’s manifest based on the distance to the target waypoint. The returned response will detail the route information including the expected time of arrival. Most ship actions are unavailable until the ship has arrived at it’s destination. To travel between systems, see the ship’s Warp or Jump actions.
negotiate_contract
Negotiate a new contract with the HQ. In order to negotiate a new contract, an agent must not have ongoing or offered contracts over the allowed maximum amount. Currently the maximum contracts an agent can have at a time is 1. Once a contract is negotiated, it is added to the list of contracts offered to the agent, which the agent can then accept. The ship must be present at any waypoint with a faction present to negotiate a contract with that faction.
orbit_ship
Attempt to move your ship into orbit at its current location. The request will only succeed if your ship is capable of moving into orbit at the time of the request. Orbiting ships are able to do actions that require the ship to be above surface such as navigating or extracting, but cannot access elements in their current waypoint, such as the market or a shipyard. The endpoint is idempotent - successive calls will succeed even if the ship is already in orbit.
patch_ship_nav
Update the nav configuration of a ship. Currently only supports configuring the Flight Mode of the ship, which affects its speed and fuel consumption.
purchase_cargo
Purchase cargo from a market. The ship must be docked in a waypoint that has Marketplace trait, and the market must be selling a good to be able to purchase it. The maximum amount of units of a good that can be purchased in each transaction are denoted by the tradeVolume value of the good, which can be viewed by using the Get Market action. Purchased goods are added to the ship’s cargo hold.
purchase_ship
Purchase a ship from a Shipyard. In order to use this function, a ship under your agent’s ownership must be in a waypoint that has the Shipyard trait, and the Shipyard must sell the type of the desired ship. Shipyards typically offer ship types, which are predefined templates of ships that have dedicated roles. A template comes with a preset of an engine, a reactor, and a frame. It may also include a few modules and mounts.
refuel_ship
Refuel your ship by buying fuel from the local market. Requires the ship to be docked in a waypoint that has the Marketplace trait, and the market must be selling fuel in order to refuel. Each fuel bought from the market replenishes 100 units in your ship’s fuel. Ships will always be refuel to their frame’s maximum fuel capacity when using this action.
remove_mount
Remove a mount from a ship. The ship must be docked in a waypoint that has the Shipyard trait, and must have the desired mount that it wish to remove installed. A removal fee will be deduced from the agent by the Shipyard.
remove_ship_module
Remove a module from a ship. The module will be placed in cargo.
repair_ship
Repair a ship, restoring the ship to maximum condition. The ship must be docked at a waypoint that has the Shipyard trait in order to use this function. To preview the cost of repairing the ship, use the Get action.
scrap_ship
Scrap a ship, removing it from the game and returning a portion of the ship’s value to the agent. The ship must be docked in a waypoint that has the Shipyard trait in order to use this function. To preview the amount of value that will be returned, use the Get Ship action.
sell_cargo
Sell cargo in your ship to a market that trades this cargo. The ship must be docked in a waypoint that has the Marketplace trait in order to use this function.
ship_refine
Attempt to refine the raw materials on your ship. The request will only succeed if your ship is capable of refining at the time of the request. In order to be able to refine, a ship must have goods that can be refined and have installed a Refinery module that can refine it. When refining, 100 basic goods will be converted into 10 processed goods.
siphon_resources
Siphon gases or other resources from gas giants. The ship must be in orbit to be able to siphon and must have siphon mounts and a gas processor installed.
transfer_cargo
Transfer cargo between ships. The receiving ship must be in the same waypoint as the transferring ship, and it must able to hold the additional cargo after the transfer is complete. Both ships also must be in the same state, either both are docked or both are orbiting. The response body’s cargo shows the cargo of the transferring ship after the transfer is complete.
warp_ship
Warp your ship to a target destination in another system. The ship must be in orbit to use this function and must have the Warp Drive module installed. Warping will consume the necessary fuel from the ship’s manifest. The returned response will detail the route information including the expected time of arrival. Most ship actions are unavailable until the ship has arrived at its destination.