Module systems_api

Module systems_api 

Enums

GetConstructionError
struct for typed errors of method get_construction
GetJumpGateError
struct for typed errors of method get_jump_gate
GetMarketError
struct for typed errors of method get_market
GetShipyardError
struct for typed errors of method get_shipyard
GetSystemError
struct for typed errors of method get_system
GetSystemWaypointsError
struct for typed errors of method get_system_waypoints
GetSystemsError
struct for typed errors of method get_systems
GetWaypointError
struct for typed errors of method get_waypoint
SupplyConstructionError
struct for typed errors of method supply_construction

Functions

get_construction
Get construction details for a waypoint. Requires a waypoint with a property of isUnderConstruction to be true.
get_jump_gate
Get jump gate details for a waypoint. Requires a waypoint of type JUMP_GATE to use. Waypoints connected to this jump gate can be
get_market
Retrieve imports, exports and exchange data from a marketplace. Requires a waypoint that has the Marketplace trait to use. Send a ship to the waypoint to access trade good prices and recent transactions. Refer to the Market Overview page to gain better a understanding of the market in the game.
get_shipyard
Get the shipyard for a waypoint. Requires a waypoint that has the Shipyard trait to use. Send a ship to the waypoint to access data on ships that are currently available for purchase and recent transactions.
get_system
Get the details of a system.
get_system_waypoints
Return a paginated list of all of the waypoints for a given system. If a waypoint is uncharted, it will return the Uncharted trait instead of its actual traits.
get_systems
Return a paginated list of all systems.
get_waypoint
View the details of a waypoint. If the waypoint is uncharted, it will return the ‘Uncharted’ trait instead of its actual traits.
supply_construction
Supply a construction site with the specified good. Requires a waypoint with a property of isUnderConstruction to be true. The good must be in your ship’s cargo. The good will be removed from your ship’s cargo and added to the construction site’s materials.