pub struct ConstructionMaterial {
pub trade_symbol: TradeSymbol,
pub required: i32,
pub fulfilled: i32,
}Expand description
ConstructionMaterial : The details of the required construction materials for a given waypoint under construction.
Fields
trade_symbol: TradeSymbolrequired: i32The number of units required.
fulfilled: i32The number of units fulfilled toward the required amount.
Implementations
Sourceimpl ConstructionMaterial
impl ConstructionMaterial
Sourcepub fn new(
trade_symbol: TradeSymbol,
required: i32,
fulfilled: i32,
) -> ConstructionMaterial
pub fn new( trade_symbol: TradeSymbol, required: i32, fulfilled: i32, ) -> ConstructionMaterial
The details of the required construction materials for a given waypoint under construction.