pub struct PatchShipNav200Response {
pub data: Box<PatchShipNav200ResponseData>,
}Expand description
PatchShipNav200Response : Success response for updating the nav configuration of a ship.
Fields
data: Box<PatchShipNav200ResponseData>Implementations
Sourcepub fn new(data: PatchShipNav200ResponseData) -> PatchShipNav200Response
pub fn new(data: PatchShipNav200ResponseData) -> PatchShipNav200Response
Success response for updating the nav configuration of a ship.