pub struct ShipConditionEvent {
pub symbol: Symbol,
pub component: Component,
pub name: String,
pub description: String,
}Expand description
ShipConditionEvent : An event that represents damage or wear to a ship’s reactor, frame, or engine, reducing the condition of the ship.
Fields
symbol: Symbolcomponent: Componentname: StringThe name of the event.
description: StringA description of the event.
Implementations