Module ship_module
space_
traders_
api
0.1.2
Module ship_
module
Module Items
Structs
Enums
In space_
traders_
api::
models
space_traders_api
::
models
Module
ship_
module
Structs

Ship
Module
ShipModule : A module can be installed in a ship and provides a set of capabilities such as storage space or quarters for crew. Module installations are permanent.
Enums

Symbol
The symbol of the module.