pub struct ShipMount {
pub symbol: Symbol,
pub name: String,
pub description: Option<String>,
pub strength: Option<i32>,
pub deposits: Option<Vec<Deposits>>,
pub requirements: Box<ShipRequirements>,
}Expand description
ShipMount : A mount is installed on the exterier of a ship.
Fields
symbol: SymbolSymbo of this mount.
name: StringName of this mount.
description: Option<String>Description of this mount.
strength: Option<i32>Mounts that have this value, such as mining lasers, denote how powerful this mount’s capabilities are.
deposits: Option<Vec<Deposits>>Mounts that have this value denote what goods can be produced from using the mount.
requirements: Box<ShipRequirements>Implementations