pub struct ShipReactor {
pub symbol: Symbol,
pub name: String,
pub description: String,
pub condition: f64,
pub integrity: f64,
pub power_output: i32,
pub requirements: Box<ShipRequirements>,
pub quality: f64,
}Expand description
ShipReactor : The reactor of the ship. The reactor is responsible for powering the ship’s systems and weapons.
Fields
symbol: SymbolSymbol of the reactor.
name: StringName of the reactor.
description: StringDescription of the reactor.
condition: f64The repairable condition of a component. A value of 0 indicates the component needs significant repairs, while a value of 1 indicates the component is in near perfect condition. As the condition of a component is repaired, the overall integrity of the component decreases.
integrity: f64The overall integrity of the component, which determines the performance of the component. A value of 0 indicates that the component is almost completely degraded, while a value of 1 indicates that the component is in near perfect condition. The integrity of the component is non-repairable, and represents permanent wear over time.
power_output: i32The amount of power provided by this reactor. The more power a reactor provides to the ship, the lower the cooldown it gets when using a module or mount that taxes the ship’s power.
requirements: Box<ShipRequirements>quality: f64The overall quality of the component, which determines the quality of the component. High quality components return more ships parts and ship plating when a ship is scrapped. But also require more of these parts to repair. This is transparent to the player, as the parts are bought from/sold to the marketplace.
Implementations
Sourceimpl ShipReactor
impl ShipReactor