Survey

Struct Survey 

pub struct Survey {
    pub signature: String,
    pub symbol: String,
    pub deposits: Vec<SurveyDeposit>,
    pub expiration: String,
    pub size: Size,
}
Survey : A resource survey of a waypoint, detailing a specific extraction location and the types of resources that can be found there.

Fields

signature: String

A unique signature for the location of this survey. This signature is verified when attempting an extraction using this survey.

symbol: String

The symbol of the waypoint that this survey is for.

deposits: Vec<SurveyDeposit>

A list of deposits that can be found at this location. A ship will extract one of these deposits when using this survey in an extraction request. If multiple deposits of the same type are present, the chance of extracting that deposit is increased.

expiration: String

The date and time when the survey expires. After this date and time, the survey will no longer be available for extraction.

size: Size

The size of the deposit. This value indicates how much can be extracted from the survey before it is exhausted.

Implementations

Source

impl Survey

pub fn new( signature: String, symbol: String, deposits: Vec<SurveyDeposit>, expiration: String, size: Size, ) -> Survey

A resource survey of a waypoint, detailing a specific extraction location and the types of resources that can be found there.