pub struct System {
pub symbol: String,
pub sector_symbol: String,
pub constellation: Option<String>,
pub name: Option<String>,
pub type: SystemType,
pub x: i32,
pub y: i32,
pub waypoints: Vec<SystemWaypoint>,
pub factions: Vec<SystemFaction>,
}Expand description
System : System details.
Fields
symbol: StringThe symbol of the system.
sector_symbol: StringThe symbol of the sector.
constellation: Option<String>The constellation that the system is part of.
name: Option<String>The name of the system.
type: SystemTypex: i32Relative position of the system in the sector in the x axis.
y: i32Relative position of the system in the sector in the y axis.
waypoints: Vec<SystemWaypoint>Waypoints in this system.
factions: Vec<SystemFaction>Factions that control this system.
Implementations
Sourceimpl System
impl System
Sourcepub fn new(
symbol: String,
sector_symbol: String,
type: SystemType,
x: i32,
y: i32,
waypoints: Vec<SystemWaypoint>,
factions: Vec<SystemFaction>,
) -> System
pub fn new( symbol: String, sector_symbol: String, type: SystemType, x: i32, y: i32, waypoints: Vec<SystemWaypoint>, factions: Vec<SystemFaction>, ) -> System
System details.