pub struct SystemWaypoint {
pub symbol: String,
pub type: WaypointType,
pub x: i32,
pub y: i32,
pub orbitals: Vec<WaypointOrbital>,
pub orbits: Option<String>,
}Expand description
SystemWaypoint : Waypoint details.
Fields
symbol: StringThe symbol of the waypoint.
type: WaypointTypex: i32Relative position of the waypoint on the system’s x axis. This is not an absolute position in the universe.
y: i32Relative position of the waypoint on the system’s y axis. This is not an absolute position in the universe.
orbitals: Vec<WaypointOrbital>Waypoints that orbit this waypoint.
orbits: Option<String>The symbol of the parent waypoint, if this waypoint is in orbit around another waypoint. Otherwise this value is undefined.
Implementations
Sourceimpl SystemWaypoint
impl SystemWaypoint
Sourcepub fn new(
symbol: String,
type: WaypointType,
x: i32,
y: i32,
orbitals: Vec<WaypointOrbital>,
) -> SystemWaypoint
pub fn new( symbol: String, type: WaypointType, x: i32, y: i32, orbitals: Vec<WaypointOrbital>, ) -> SystemWaypoint
Waypoint details.