pub struct Waypoint {
pub symbol: String,
pub type: WaypointType,
pub system_symbol: String,
pub x: i32,
pub y: i32,
pub orbitals: Vec<WaypointOrbital>,
pub orbits: Option<String>,
pub faction: Option<Box<WaypointFaction>>,
pub traits: Vec<WaypointTrait>,
pub modifiers: Option<Vec<WaypointModifier>>,
pub chart: Option<Box<Chart>>,
pub is_under_construction: bool,
}Expand description
Waypoint : A waypoint is a location that ships can travel to such as a Planet, Moon or Space Station.
Fields
symbol: StringThe symbol of the waypoint.
type: WaypointTypesystem_symbol: StringThe symbol of the system.
x: i32Relative position of the waypoint on the system’s x axis. This is not an absolute position in the universe.
y: i32Relative position of the waypoint on the system’s y axis. This is not an absolute position in the universe.
orbitals: Vec<WaypointOrbital>Waypoints that orbit this waypoint.
orbits: Option<String>The symbol of the parent waypoint, if this waypoint is in orbit around another waypoint. Otherwise this value is undefined.
faction: Option<Box<WaypointFaction>>traits: Vec<WaypointTrait>The traits of the waypoint.
modifiers: Option<Vec<WaypointModifier>>The modifiers of the waypoint.
chart: Option<Box<Chart>>is_under_construction: boolTrue if the waypoint is under construction.
Implementations
Sourceimpl Waypoint
impl Waypoint
Sourcepub fn new(
symbol: String,
type: WaypointType,
system_symbol: String,
x: i32,
y: i32,
orbitals: Vec<WaypointOrbital>,
traits: Vec<WaypointTrait>,
is_under_construction: bool,
) -> Waypoint
pub fn new( symbol: String, type: WaypointType, system_symbol: String, x: i32, y: i32, orbitals: Vec<WaypointOrbital>, traits: Vec<WaypointTrait>, is_under_construction: bool, ) -> Waypoint
A waypoint is a location that ships can travel to such as a Planet, Moon or Space Station.