Enums
- Accept
Contract Error - struct for typed errors of method
accept_contract - Deliver
Contract Error - struct for typed errors of method
deliver_contract - Fulfill
Contract Error - struct for typed errors of method
fulfill_contract - GetContract
Error - struct for typed errors of method
get_contract - GetContracts
Error - struct for typed errors of method
get_contracts
Functions
- accept_
contract - Accept a contract by ID. You can only accept contracts that were offered to you, were not accepted yet, and whose deadlines has not passed yet.
- deliver_
contract - Deliver cargo to a contract. In order to use this API, a ship must be at the delivery location (denoted in the delivery terms as
destinationSymbolof a contract) and must have a number of units of a good required by this contract in its cargo. Cargo that was delivered will be removed from the ship’s cargo. - fulfill_
contract - Fulfill a contract. Can only be used on contracts that have all of their delivery terms fulfilled.
- get_
contract - Get the details of a contract by ID.
- get_
contracts - Return a paginated list of all your contracts.