Enums
- GetConstruction
Error - struct for typed errors of method
get_construction - GetJump
Gate Error - struct for typed errors of method
get_jump_gate - GetMarket
Error - struct for typed errors of method
get_market - GetShipyard
Error - struct for typed errors of method
get_shipyard - GetSystem
Error - struct for typed errors of method
get_system - GetSystem
Waypoints Error - struct for typed errors of method
get_system_waypoints - GetSystems
Error - struct for typed errors of method
get_systems - GetWaypoint
Error - struct for typed errors of method
get_waypoint - Supply
Construction Error - struct for typed errors of method
supply_construction
Functions
- get_
construction - Get construction details for a waypoint. Requires a waypoint with a property of
isUnderConstructionto be true. - get_
jump_ gate - Get jump gate details for a waypoint. Requires a waypoint of type
JUMP_GATEto use. Waypoints connected to this jump gate can be - get_
market - Retrieve imports, exports and exchange data from a marketplace. Requires a waypoint that has the
Marketplacetrait to use. Send a ship to the waypoint to access trade good prices and recent transactions. Refer to the Market Overview page to gain better a understanding of the market in the game. - get_
shipyard - Get the shipyard for a waypoint. Requires a waypoint that has the
Shipyardtrait to use. Send a ship to the waypoint to access data on ships that are currently available for purchase and recent transactions. - get_
system - Get the details of a system.
- get_
system_ waypoints - Return a paginated list of all of the waypoints for a given system. If a waypoint is uncharted, it will return the
Unchartedtrait instead of its actual traits. - get_
systems - Return a paginated list of all systems.
- get_
waypoint - View the details of a waypoint. If the waypoint is uncharted, it will return the ‘Uncharted’ trait instead of its actual traits.
- supply_
construction - Supply a construction site with the specified good. Requires a waypoint with a property of
isUnderConstructionto be true. The good must be in your ship’s cargo. The good will be removed from your ship’s cargo and added to the construction site’s materials.