pub struct ShipEngine {
pub symbol: Symbol,
pub name: String,
pub description: String,
pub condition: f64,
pub integrity: f64,
pub speed: i32,
pub requirements: Box<ShipRequirements>,
pub quality: f64,
}Expand description
ShipEngine : The engine determines how quickly a ship travels between waypoints.
Fields
symbol: SymbolThe symbol of the engine.
name: StringThe name of the engine.
description: StringThe description of the engine.
condition: f64The repairable condition of a component. A value of 0 indicates the component needs significant repairs, while a value of 1 indicates the component is in near perfect condition. As the condition of a component is repaired, the overall integrity of the component decreases.
integrity: f64The overall integrity of the component, which determines the performance of the component. A value of 0 indicates that the component is almost completely degraded, while a value of 1 indicates that the component is in near perfect condition. The integrity of the component is non-repairable, and represents permanent wear over time.
speed: i32The speed stat of this engine. The higher the speed, the faster a ship can travel from one point to another. Reduces the time of arrival when navigating the ship.
requirements: Box<ShipRequirements>quality: f64The overall quality of the component, which determines the quality of the component. High quality components return more ships parts and ship plating when a ship is scrapped. But also require more of these parts to repair. This is transparent to the player, as the parts are bought from/sold to the marketplace.
Implementations
Sourceimpl ShipEngine
impl ShipEngine