pub struct ShipFrame {
pub symbol: Symbol,
pub name: String,
pub description: String,
pub condition: f64,
pub integrity: f64,
pub module_slots: i32,
pub mounting_points: i32,
pub fuel_capacity: i32,
pub requirements: Box<ShipRequirements>,
pub quality: f64,
}Expand description
ShipFrame : The frame of the ship. The frame determines the number of modules and mounting points of the ship, as well as base fuel capacity. As the condition of the frame takes more wear, the ship will become more sluggish and less maneuverable.
Fields
symbol: SymbolSymbol of the frame.
name: StringName of the frame.
description: StringDescription of the frame.
condition: f64The repairable condition of a component. A value of 0 indicates the component needs significant repairs, while a value of 1 indicates the component is in near perfect condition. As the condition of a component is repaired, the overall integrity of the component decreases.
integrity: f64The overall integrity of the component, which determines the performance of the component. A value of 0 indicates that the component is almost completely degraded, while a value of 1 indicates that the component is in near perfect condition. The integrity of the component is non-repairable, and represents permanent wear over time.
module_slots: i32The amount of slots that can be dedicated to modules installed in the ship. Each installed module take up a number of slots, and once there are no more slots, no new modules can be installed.
mounting_points: i32The amount of slots that can be dedicated to mounts installed in the ship. Each installed mount takes up a number of points, and once there are no more points remaining, no new mounts can be installed.
fuel_capacity: i32The maximum amount of fuel that can be stored in this ship. When refueling, the ship will be refueled to this amount.
requirements: Box<ShipRequirements>quality: f64The overall quality of the component, which determines the quality of the component. High quality components return more ships parts and ship plating when a ship is scrapped. But also require more of these parts to repair. This is transparent to the player, as the parts are bought from/sold to the marketplace.
Implementations
Sourceimpl ShipFrame
impl ShipFrame
Sourcepub fn new(
symbol: Symbol,
name: String,
description: String,
condition: f64,
integrity: f64,
module_slots: i32,
mounting_points: i32,
fuel_capacity: i32,
requirements: ShipRequirements,
quality: f64,
) -> ShipFrame
pub fn new( symbol: Symbol, name: String, description: String, condition: f64, integrity: f64, module_slots: i32, mounting_points: i32, fuel_capacity: i32, requirements: ShipRequirements, quality: f64, ) -> ShipFrame
The frame of the ship. The frame determines the number of modules and mounting points of the ship, as well as base fuel capacity. As the condition of the frame takes more wear, the ship will become more sluggish and less maneuverable.