Struct Survey Copy item path Source pub struct Survey {
pub signature: String ,
pub symbol: String ,
pub deposits: Vec <SurveyDeposit >,
pub expiration: String ,
pub size: Size ,
}Expand description Survey : A resource survey of a waypoint, detailing a specific extraction location and the types of resources that can be found there.
A unique signature for the location of this survey. This signature is verified when attempting an extraction using this survey.
The symbol of the waypoint that this survey is for.
A list of deposits that can be found at this location. A ship will extract one of these deposits when using this survey in an extraction request. If multiple deposits of the same type are present, the chance of extracting that deposit is increased.
The date and time when the survey expires. After this date and time, the survey will no longer be available for extraction.
The size of the deposit. This value indicates how much can be extracted from the survey before it is exhausted.
A resource survey of a waypoint, detailing a specific extraction location and the types of resources that can be found there.
Performs copy-assignment from
source.
Read more Formats the value using the given formatter.
Read more Returns the “default value” for a type.
Read more Deserialize this value from the given Serde deserializer.
Read more Tests for self and other values to be equal, and is used by ==.
Tests for !=. The default implementation is almost always sufficient,
and should not be overridden without very good reason.
Serialize this value into the given Serde serializer.
Read more Immutably borrows from an owned value.
Read more Mutably borrows from an owned value.
Read more 🔬 This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from
self to
dest.
Read more Returns the argument unchanged.
Instruments this type with the provided
Span, returning an
Instrumented wrapper.
Read more Calls U::from(self).
That is, this conversion is whatever the implementation of
From <T> for U chooses to do.
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning.
Read more Uses borrowed data to replace owned data, usually by cloning.
Read more The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.